@@ -37,17 +37,23 @@ class ScheduledJob(models.Model):
     kwargs_pickled = models.TextField()
 
     def _get_args(self):
-        return cPickle.loads(str(self.args_pickled))
+        return self._unpickle(self.args_pickled)
     def _set_args(self, value):
-        self.args_pickled = cPickle.dumps(tuple(value))
+        self.args_pickled = self._pickle(value)
     args = property(_get_args, _set_args)
 
     def _get_kwargs(self):
-        return cPickle.loads(str(self.kwargs_pickled))
+        return self._unpickle(self.kwargs_pickled)
     def _set_kwargs(self, value):
-        self.kwargs_pickled = cPickle.dumps(value)
+        self.kwargs_pickled = self._pickle(value)
     kwargs = property(_get_kwargs, _set_kwargs)
 
+    def _pickle(self, value):
+        return cPickle.dumps(value).encode('base64')
+
+    def _unpickle(self, s):
+        return cPickle.loads(str(s).decode('base64'))
+
     def __repr__(self):
         return '<ScheduledJob (%s) callable=%r>' % (
                     self.status, self.callable_name)
